@@ -11,15 +11,14 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
+"""Interfaces
 """
-$Id: layer.py 197 2007-04-13 05:03:32Z rineichen $
-"""
-
-from z3c.menu.ready2go.i18n import MessageFactory as _
 import zope.interface
 import zope.schema
 import zope.viewlet.interfaces
 
+from z3c.menu.ready2go.i18n import MessageFactory as _
+
 
 class IMenuManager(zope.viewlet.interfaces.IViewletManager):
     """Generic nenu manager."""
@@ -42,62 +41,62 @@ class IMenuItem(zope.viewlet.interfaces.IViewlet):
     title = zope.schema.TextLine(
         title=_('Title'),
         description=_('Menu item title'),
-        default=u''
-        )
+        default=''
+    )
 
     viewName = zope.schema.TextLine(
         title=_('View name'),
         description=_('Name of the view which the menu points to.'),
-        default=u''
-        )
+        default=''
+    )
 
     weight = zope.schema.TextLine(
         title=_('Weight'),
         description=_('Weight of the menu item order.'),
-        default=u''
-        )
+        default=''
+    )
 
     cssActive = zope.schema.TextLine(
         title=_('Active CSS class name'),
         description=_('CSS class name for active menu items'),
-        default=u''
-        )
+        default=''
+    )
 
     cssInActive = zope.schema.TextLine(
         title=_('In-Active CSS class name'),
         description=_('CSS class name for inactive menu items'),
-        default=u''
-        )
+        default=''
+    )
 
     css = zope.schema.TextLine(
         title=_('CSS class name'),
         description=_('CSS class name'),
-        default=u''
-        )
+        default=''
+    )
 
     available = zope.schema.Bool(
         title=_('Available'),
         description=_('Marker for available menu item'),
         default=True
-        )
+    )
 
     selected = zope.schema.Bool(
         title=_('Selected'),
         description=_('Marker for selected menu item'),
         default=False
-        )
+    )
 
     url = zope.schema.TextLine(
         title=_('URL'),
         description=_('URL or other url like javascript function.'),
-        default=u''
-        )
+        default=''
+    )
 
     subMenuProviderName = zope.schema.TextLine(
         title=_('Sub menu provider name'),
         description=_('Name of the sub menu provider.'),
-        default=u''
-        )
+        default=''
+    )
 
     def getURLContext():
         """Returns the context the base url."""
@@ -113,7 +112,7 @@ class ISelectedChecker(zope.interface.Interface):
         title=_('Selected'),
         description=_('Marker for selected menu item'),
         default=False
-        )
+    )
 
 
 class IGlobalMenuItem(IMenuItem):
