@@ -11,27 +11,35 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
+"""Test Setup
 """
-$Id: __init__.py 97 2007-03-29 22:58:27Z rineichen $
-"""
-
 import doctest
 import unittest
-import zope.interface
+
 import zope.component
+import zope.interface
+from zope.component import hooks
+from zope.interface.verify import verifyClass
+from zope.interface.verify import verifyObject
+from zope.site.testing import siteSetUp
+from zope.site.testing import siteTearDown
 from zope.traversing.browser.interfaces import IAbsoluteURL
 from zope.traversing.interfaces import IPhysicallyLocatable
-from zope.site import hooks
-from zope.app.testing import setup
 
-import z3c.testing
 from z3c.menu.ready2go import interfaces
 from z3c.menu.ready2go import item
 from z3c.menu.ready2go import manager
 from z3c.menu.ready2go import testing
 
 
-class CheckerStub(object):
+flags = (
+    doctest.NORMALIZE_WHITESPACE
+    | doctest.ELLIPSIS
+    | doctest.IGNORE_EXCEPTION_DETAIL
+)
+
+
+class CheckerStub:
     """Just a checker stub."""
 
     def __init__(self, context, request, view, menu, item):
@@ -50,13 +58,12 @@ class CheckerStub(object):
         return True
 
 
-class ParentStub(object):
+@zope.interface.implementer(IPhysicallyLocatable)
+class ParentStub:
     """Just an object supporting a context attribtute."""
 
     __name__ = __parent__ = context = None
 
-    zope.interface.implements(IPhysicallyLocatable)
-
     def __init__(self, path=('a', 'b')):
         self.path = path
 
@@ -67,19 +74,36 @@ class ParentStub(object):
         return self.path
 
 
-class AbsoulteURLStub(object):
+class AbsoulteURLStub:
     """Absolute url stub."""
 
     def __init__(self, context, request):
         pass
 
     def __str__(self):
-        return u'here'
+        return 'here'
 
     __call__ = __str__
 
 
-class MenuManagerTest(z3c.testing.InterfaceBaseTest):
+class InterfaceBaseTest(unittest.TestCase):
+    """Base test for IContainer including interface test."""
+
+    def makeTestObject(self):
+        return self.getTestClass()(*self.getTestPos())
+
+    def test_verifyClass(self):
+        # class test
+        self.assertTrue(
+            verifyClass(self.getTestInterface(), self.getTestClass()))
+
+    def test_verifyObject(self):
+        # object test
+        self.assertTrue(
+            verifyObject(self.getTestInterface(), self.makeTestObject()))
+
+
+class MenuManagerTest(InterfaceBaseTest):
 
     def getTestInterface(self):
         return interfaces.IMenuManager
@@ -91,16 +115,20 @@ class MenuManagerTest(z3c.testing.InterfaceBaseTest):
         return (None, None, None)
 
 
-class GlobalMenuItemTest(z3c.testing.InterfaceBaseTest):
+class GlobalMenuItemTest(InterfaceBaseTest):
 
     def setUp(self):
-        site = setup.placefulSetUp(site=True)
+        site = siteSetUp(True)
         hooks.setSite(site)
         zope.component.provideAdapter(AbsoulteURLStub, (None, None),
-            IAbsoluteURL)
-        zope.component.provideAdapter(CheckerStub, (None, None, None, None,
-            None), interfaces.ISelectedChecker)
-        super(GlobalMenuItemTest, self).setUp()
+                                      IAbsoluteURL)
+        zope.component.provideAdapter(
+            CheckerStub, (None, None, None, None, None),
+            interfaces.ISelectedChecker)
+        super().setUp()
+
+    def tearDown(self):
+        siteTearDown()
 
     def getTestInterface(self):
         return interfaces.IGlobalMenuItem
@@ -112,16 +140,19 @@ class GlobalMenuItemTest(z3c.testing.InterfaceBaseTest):
         return (ParentStub(), None, ParentStub(), None)
 
 
-class SiteMenuItemTest(z3c.testing.InterfaceBaseTest):
+class SiteMenuItemTest(InterfaceBaseTest):
 
     def setUp(self):
-        site = setup.placefulSetUp(site=True)
+        site = siteSetUp(True)
         hooks.setSite(site)
         zope.component.provideAdapter(AbsoulteURLStub, (None, None),
-            IAbsoluteURL)
-        zope.component.provideAdapter(CheckerStub, (None, None, None, None,
-            None), interfaces.ISelectedChecker)
-        super(SiteMenuItemTest, self).setUp()
+                                      IAbsoluteURL)
+        zope.component.provideAdapter(
+            CheckerStub, (None, None, None, None, None),
+            interfaces.ISelectedChecker)
+
+    def tearDown(self):
+        siteTearDown()
 
     def getTestInterface(self):
         return interfaces.ISiteMenuItem
@@ -133,12 +164,18 @@ class SiteMenuItemTest(z3c.testing.InterfaceBaseTest):
         return (ParentStub(), None, ParentStub(), None)
 
 
-class ContextMenuItemTest(z3c.testing.InterfaceBaseTest):
+class ContextMenuItemTest(InterfaceBaseTest):
 
     def setUp(self):
-        zope.component.provideAdapter(CheckerStub, (None, None, None, None,
-            None), interfaces.ISelectedChecker)
-        super(ContextMenuItemTest, self).setUp()
+        zope.component.testing.setUp()
+        zope.component.provideAdapter(AbsoulteURLStub, (None, None),
+                                      IAbsoluteURL)
+        zope.component.provideAdapter(
+            CheckerStub, (None, None, None, None, None),
+            interfaces.ISelectedChecker)
+
+    def tearDown(self):
+        zope.component.testing.tearDown()
 
     def getTestInterface(self):
         return interfaces.IContextMenuItem
@@ -153,18 +190,15 @@ class ContextMenuItemTest(z3c.testing.InterfaceBaseTest):
 def test_suite():
     return unittest.TestSuite((
         doctest.DocFileSuite('README.txt',
-            setUp=testing.setUp, tearDown=testing.tearDown,
-            optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS,
-            ),
+                             setUp=testing.setUp, tearDown=testing.tearDown,
+                             optionflags=flags,
+                             ),
         doctest.DocFileSuite('zcml.txt',
-            setUp=testing.setUp, tearDown=testing.tearDown,
-            optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS,
-            ),
-        unittest.makeSuite(MenuManagerTest),
-        unittest.makeSuite(GlobalMenuItemTest),
-        unittest.makeSuite(SiteMenuItemTest),
-        unittest.makeSuite(ContextMenuItemTest),
-        ))
-
-if __name__ == '__main__':
-    unittest.main(defaultTest='test_suite')
+                             setUp=testing.setUp, tearDown=testing.tearDown,
+                             optionflags=flags,
+                             ),
+        unittest.defaultTestLoader.loadTestsFromTestCase(MenuManagerTest),
+        unittest.defaultTestLoader.loadTestsFromTestCase(GlobalMenuItemTest),
+        unittest.defaultTestLoader.loadTestsFromTestCase(SiteMenuItemTest),
+        unittest.defaultTestLoader.loadTestsFromTestCase(ContextMenuItemTest),
+    ))
